#ifndef OS_SPEC_CFG_H_
#define OS_SPEC_CFG_H_

#include "x502api.h"


//#define OSSPEC_USE_MUTEX
//#define OSSPEC_USE_EVENTS
//#define OSSPEC_USE_THREADS


#define OSSPEC_ERR_MUTEX_INVALID_HANDLE     X502_ERR_MUTEX_INVALID_HANDLE
#define OSSPEC_ERR_MUTEX_LOCK_TOUT          X502_ERR_MUTEX_LOCK_TOUT
#define OSSPEC_ERR_MUTEX_RELEASE            X502_ERR_MUTEX_RELEASE


#define OSSPEC_ERR_EVENT_INVALID_HANDLE     OSSPEC_ERR_MUTEX_INVALID_HANDLE
#define OSSPEC_ERR_EVENT_WAIT_TOUT          OSSPEC_ERR_MUTEX_LOCK_TOUT


#define OSSPEC_ERR_THREAD_INVALID_HANDLE    OSSPEC_ERR_MUTEX_INVALID_HANDLE
#define OSSPEC_ERR_THREAD_WAIT_TOUT         X502_ERR_THREAD_STOP




#endif
